from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.NetworkManagement.Snmp
ASN_UNIVERSAL: UInt32 = 0
ASN_APPLICATION: UInt32 = 64
ASN_CONTEXT: UInt32 = 128
ASN_PRIVATE: UInt32 = 192
ASN_PRIMITIVE: UInt32 = 0
ASN_CONSTRUCTOR: UInt32 = 32
SNMP_ACCESS_NONE: UInt32 = 0
SNMP_ACCESS_NOTIFY: UInt32 = 1
SNMP_ACCESS_READ_ONLY: UInt32 = 2
SNMP_ACCESS_READ_WRITE: UInt32 = 3
SNMP_ACCESS_READ_CREATE: UInt32 = 4
SNMPAPI_NOERROR: UInt32 = 1
SNMPAPI_ERROR: UInt32 = 0
SNMP_OUTPUT_TO_EVENTLOG: UInt32 = 4
DEFAULT_SNMP_PORT_UDP: UInt32 = 161
DEFAULT_SNMP_PORT_IPX: UInt32 = 36879
DEFAULT_SNMPTRAP_PORT_UDP: UInt32 = 162
DEFAULT_SNMPTRAP_PORT_IPX: UInt32 = 36880
SNMP_MAX_OID_LEN: UInt32 = 128
SNMP_MEM_ALLOC_ERROR: UInt32 = 1
SNMP_BERAPI_INVALID_LENGTH: UInt32 = 10
SNMP_BERAPI_INVALID_TAG: UInt32 = 11
SNMP_BERAPI_OVERFLOW: UInt32 = 12
SNMP_BERAPI_SHORT_BUFFER: UInt32 = 13
SNMP_BERAPI_INVALID_OBJELEM: UInt32 = 14
SNMP_PDUAPI_UNRECOGNIZED_PDU: UInt32 = 20
SNMP_PDUAPI_INVALID_ES: UInt32 = 21
SNMP_PDUAPI_INVALID_GT: UInt32 = 22
SNMP_AUTHAPI_INVALID_VERSION: UInt32 = 30
SNMP_AUTHAPI_INVALID_MSG_TYPE: UInt32 = 31
SNMP_AUTHAPI_TRIV_AUTH_FAILED: UInt32 = 32
ASN_CONTEXTSPECIFIC: UInt32 = 128
ASN_PRIMATIVE: UInt32 = 0
SNMP_MGMTAPI_TIMEOUT: UInt32 = 40
SNMP_MGMTAPI_SELECT_FDERRORS: UInt32 = 41
SNMP_MGMTAPI_TRAP_ERRORS: UInt32 = 42
SNMP_MGMTAPI_TRAP_DUPINIT: UInt32 = 43
SNMP_MGMTAPI_NOTRAPS: UInt32 = 44
SNMP_MGMTAPI_AGAIN: UInt32 = 45
SNMP_MGMTAPI_INVALID_CTL: UInt32 = 46
SNMP_MGMTAPI_INVALID_SESSION: UInt32 = 47
SNMP_MGMTAPI_INVALID_BUFFER: UInt32 = 48
MGMCTL_SETAGENTPORT: UInt32 = 1
MAXOBJIDSIZE: UInt32 = 128
MAXOBJIDSTRSIZE: UInt32 = 1408
SNMPLISTEN_USEENTITY_ADDR: UInt32 = 0
SNMPLISTEN_ALL_ADDR: UInt32 = 1
SNMP_TRAP_COLDSTART: UInt32 = 0
SNMP_TRAP_WARMSTART: UInt32 = 1
SNMP_TRAP_LINKDOWN: UInt32 = 2
SNMP_TRAP_LINKUP: UInt32 = 3
SNMP_TRAP_AUTHFAIL: UInt32 = 4
SNMP_TRAP_EGPNEIGHBORLOSS: UInt32 = 5
SNMP_TRAP_ENTERPRISESPECIFIC: UInt32 = 6
SNMPAPI_NO_SUPPORT: UInt32 = 0
SNMPAPI_V1_SUPPORT: UInt32 = 1
SNMPAPI_V2_SUPPORT: UInt32 = 2
SNMPAPI_M2M_SUPPORT: UInt32 = 3
SNMPAPI_FAILURE: UInt32 = 0
SNMPAPI_SUCCESS: UInt32 = 1
SNMPAPI_ALLOC_ERROR: UInt32 = 2
SNMPAPI_CONTEXT_INVALID: UInt32 = 3
SNMPAPI_CONTEXT_UNKNOWN: UInt32 = 4
SNMPAPI_ENTITY_INVALID: UInt32 = 5
SNMPAPI_ENTITY_UNKNOWN: UInt32 = 6
SNMPAPI_INDEX_INVALID: UInt32 = 7
SNMPAPI_NOOP: UInt32 = 8
SNMPAPI_OID_INVALID: UInt32 = 9
SNMPAPI_OPERATION_INVALID: UInt32 = 10
SNMPAPI_OUTPUT_TRUNCATED: UInt32 = 11
SNMPAPI_PDU_INVALID: UInt32 = 12
SNMPAPI_SESSION_INVALID: UInt32 = 13
SNMPAPI_SYNTAX_INVALID: UInt32 = 14
SNMPAPI_VBL_INVALID: UInt32 = 15
SNMPAPI_MODE_INVALID: UInt32 = 16
SNMPAPI_SIZE_INVALID: UInt32 = 17
SNMPAPI_NOT_INITIALIZED: UInt32 = 18
SNMPAPI_MESSAGE_INVALID: UInt32 = 19
SNMPAPI_HWND_INVALID: UInt32 = 20
SNMPAPI_OTHER_ERROR: UInt32 = 99
SNMPAPI_TL_NOT_INITIALIZED: UInt32 = 100
SNMPAPI_TL_NOT_SUPPORTED: UInt32 = 101
SNMPAPI_TL_NOT_AVAILABLE: UInt32 = 102
SNMPAPI_TL_RESOURCE_ERROR: UInt32 = 103
SNMPAPI_TL_UNDELIVERABLE: UInt32 = 104
SNMPAPI_TL_SRC_INVALID: UInt32 = 105
SNMPAPI_TL_INVALID_PARAM: UInt32 = 106
SNMPAPI_TL_IN_USE: UInt32 = 107
SNMPAPI_TL_TIMEOUT: UInt32 = 108
SNMPAPI_TL_PDU_TOO_BIG: UInt32 = 109
SNMPAPI_TL_OTHER: UInt32 = 199
MAXVENDORINFO: UInt32 = 32
@winfunctype('snmpapi.dll')
def SnmpUtilOidCpy(pOidDst: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier), pOidSrc: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier)) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilOidAppend(pOidDst: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier), pOidSrc: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier)) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilOidNCmp(pOid1: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier), pOid2: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier), nSubIds: UInt32) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilOidCmp(pOid1: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier), pOid2: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier)) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilOidFree(pOid: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier)) -> Void: ...
@winfunctype('snmpapi.dll')
def SnmpUtilOctetsCmp(pOctets1: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString), pOctets2: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString)) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilOctetsNCmp(pOctets1: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString), pOctets2: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString), nChars: UInt32) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilOctetsCpy(pOctetsDst: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString), pOctetsSrc: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString)) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilOctetsFree(pOctets: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString)) -> Void: ...
@winfunctype('snmpapi.dll')
def SnmpUtilAsnAnyCpy(pAnyDst: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnAny), pAnySrc: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnAny)) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilAsnAnyFree(pAny: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnAny)) -> Void: ...
@winfunctype('snmpapi.dll')
def SnmpUtilVarBindCpy(pVbDst: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBind), pVbSrc: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBind)) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilVarBindFree(pVb: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBind)) -> Void: ...
@winfunctype('snmpapi.dll')
def SnmpUtilVarBindListCpy(pVblDst: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBindList), pVblSrc: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBindList)) -> Int32: ...
@winfunctype('snmpapi.dll')
def SnmpUtilVarBindListFree(pVbl: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBindList)) -> Void: ...
@winfunctype('snmpapi.dll')
def SnmpUtilMemFree(pMem: VoidPtr) -> Void: ...
@winfunctype('snmpapi.dll')
def SnmpUtilMemAlloc(nBytes: UInt32) -> VoidPtr: ...
@winfunctype('snmpapi.dll')
def SnmpUtilMemReAlloc(pMem: VoidPtr, nBytes: UInt32) -> VoidPtr: ...
@winfunctype('snmpapi.dll')
def SnmpUtilOidToA(Oid: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier)) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('snmpapi.dll')
def SnmpUtilIdsToA(Ids: POINTER(UInt32), IdLength: UInt32) -> win32more.Windows.Win32.Foundation.PSTR: ...
@winfunctype('snmpapi.dll')
def SnmpUtilPrintOid(Oid: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier)) -> Void: ...
@winfunctype('snmpapi.dll')
def SnmpUtilPrintAsnAny(pAny: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnAny)) -> Void: ...
@winfunctype('snmpapi.dll')
def SnmpSvcGetUptime() -> UInt32: ...
@winfunctype('snmpapi.dll')
def SnmpSvcSetLogLevel(nLogLevel: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_LOG) -> Void: ...
@winfunctype('snmpapi.dll')
def SnmpSvcSetLogType(nLogType: Int32) -> Void: ...
@cfunctype('snmpapi.dll', variadic=True)
def SnmpUtilDbgPrint(nLogLevel: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_LOG, szFormat: win32more.Windows.Win32.Foundation.PSTR, *__arglist) -> Void: ...
@winfunctype('mgmtapi.dll')
def SnmpMgrOpen(lpAgentAddress: win32more.Windows.Win32.Foundation.PSTR, lpAgentCommunity: win32more.Windows.Win32.Foundation.PSTR, nTimeOut: Int32, nRetries: Int32) -> VoidPtr: ...
@winfunctype('mgmtapi.dll')
def SnmpMgrCtl(session: VoidPtr, dwCtlCode: UInt32, lpvInBuffer: VoidPtr, cbInBuffer: UInt32, lpvOUTBuffer: VoidPtr, cbOUTBuffer: UInt32, lpcbBytesReturned: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mgmtapi.dll')
def SnmpMgrClose(session: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mgmtapi.dll')
def SnmpMgrRequest(session: VoidPtr, requestType: Byte, variableBindings: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBindList), errorStatus: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS), errorIndex: POINTER(Int32)) -> Int32: ...
@winfunctype('mgmtapi.dll')
def SnmpMgrStrToOid(string: win32more.Windows.Win32.Foundation.PSTR, oid: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mgmtapi.dll')
def SnmpMgrOidToStr(oid: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier), string: POINTER(win32more.Windows.Win32.Foundation.PSTR)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mgmtapi.dll')
def SnmpMgrTrapListen(phTrapAvailable: POINTER(win32more.Windows.Win32.Foundation.HANDLE)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mgmtapi.dll')
def SnmpMgrGetTrap(enterprise: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier), IPAddress: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString), genericTrap: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_GENERICTRAP), specificTrap: POINTER(Int32), timeStamp: POINTER(UInt32), variableBindings: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBindList)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('mgmtapi.dll')
def SnmpMgrGetTrapEx(enterprise: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier), agentAddress: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString), sourceAddress: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString), genericTrap: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_GENERICTRAP), specificTrap: POINTER(Int32), community: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString), timeStamp: POINTER(UInt32), variableBindings: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBindList)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype('wsnmp32.dll')
def SnmpGetTranslateMode(nTranslateMode: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_API_TRANSLATE_MODE)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpSetTranslateMode(nTranslateMode: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_API_TRANSLATE_MODE) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpGetRetransmitMode(nRetransmitMode: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_STATUS)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpSetRetransmitMode(nRetransmitMode: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_STATUS) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpGetTimeout(hEntity: IntPtr, nPolicyTimeout: POINTER(UInt32), nActualTimeout: POINTER(UInt32)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpSetTimeout(hEntity: IntPtr, nPolicyTimeout: UInt32) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpGetRetry(hEntity: IntPtr, nPolicyRetry: POINTER(UInt32), nActualRetry: POINTER(UInt32)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpSetRetry(hEntity: IntPtr, nPolicyRetry: UInt32) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpGetVendorInfo(vendorInfo: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiVENDORINFO)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpStartup(nMajorVersion: POINTER(UInt32), nMinorVersion: POINTER(UInt32), nLevel: POINTER(UInt32), nTranslateMode: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_API_TRANSLATE_MODE), nRetransmitMode: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_STATUS)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpCleanup() -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpOpen(hWnd: win32more.Windows.Win32.Foundation.HWND, wMsg: UInt32) -> IntPtr: ...
@winfunctype('wsnmp32.dll')
def SnmpClose(session: IntPtr) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpSendMsg(session: IntPtr, srcEntity: IntPtr, dstEntity: IntPtr, context: IntPtr, PDU: IntPtr) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpRecvMsg(session: IntPtr, srcEntity: POINTER(IntPtr), dstEntity: POINTER(IntPtr), context: POINTER(IntPtr), PDU: POINTER(IntPtr)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpRegister(session: IntPtr, srcEntity: IntPtr, dstEntity: IntPtr, context: IntPtr, notification: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID), state: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_STATUS) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpCreateSession(hWnd: win32more.Windows.Win32.Foundation.HWND, wMsg: UInt32, fCallBack: win32more.Windows.Win32.NetworkManagement.Snmp.SNMPAPI_CALLBACK, lpClientData: VoidPtr) -> IntPtr: ...
@winfunctype('wsnmp32.dll')
def SnmpListen(hEntity: IntPtr, lStatus: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_STATUS) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpListenEx(hEntity: IntPtr, lStatus: UInt32, nUseEntityAddr: UInt32) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpCancelMsg(session: IntPtr, reqId: Int32) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpStartupEx(nMajorVersion: POINTER(UInt32), nMinorVersion: POINTER(UInt32), nLevel: POINTER(UInt32), nTranslateMode: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_API_TRANSLATE_MODE), nRetransmitMode: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_STATUS)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpCleanupEx() -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpStrToEntity(session: IntPtr, string: win32more.Windows.Win32.Foundation.PSTR) -> IntPtr: ...
@winfunctype('wsnmp32.dll')
def SnmpEntityToStr(entity: IntPtr, size: UInt32, string: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpFreeEntity(entity: IntPtr) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpStrToContext(session: IntPtr, string: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOCTETS)) -> IntPtr: ...
@winfunctype('wsnmp32.dll')
def SnmpContextToStr(context: IntPtr, string: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOCTETS)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpFreeContext(context: IntPtr) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpSetPort(hEntity: IntPtr, nPort: UInt32) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpCreatePdu(session: IntPtr, PDU_type: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_PDU_TYPE, request_id: Int32, error_status: Int32, error_index: Int32, varbindlist: IntPtr) -> IntPtr: ...
@winfunctype('wsnmp32.dll')
def SnmpGetPduData(PDU: IntPtr, PDU_type: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_PDU_TYPE), request_id: POINTER(Int32), error_status: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR), error_index: POINTER(Int32), varbindlist: POINTER(IntPtr)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpSetPduData(PDU: IntPtr, PDU_type: POINTER(Int32), request_id: POINTER(Int32), non_repeaters: POINTER(Int32), max_repetitions: POINTER(Int32), varbindlist: POINTER(IntPtr)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpDuplicatePdu(session: IntPtr, PDU: IntPtr) -> IntPtr: ...
@winfunctype('wsnmp32.dll')
def SnmpFreePdu(PDU: IntPtr) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpCreateVbl(session: IntPtr, name: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID), value: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiVALUE)) -> IntPtr: ...
@winfunctype('wsnmp32.dll')
def SnmpDuplicateVbl(session: IntPtr, vbl: IntPtr) -> IntPtr: ...
@winfunctype('wsnmp32.dll')
def SnmpFreeVbl(vbl: IntPtr) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpCountVbl(vbl: IntPtr) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpGetVb(vbl: IntPtr, index: UInt32, name: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID), value: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiVALUE)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpSetVb(vbl: IntPtr, index: UInt32, name: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID), value: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiVALUE)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpDeleteVb(vbl: IntPtr, index: UInt32) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpGetLastError(session: IntPtr) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpStrToOid(string: win32more.Windows.Win32.Foundation.PSTR, dstOID: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpOidToStr(srcOID: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID), size: UInt32, string: win32more.Windows.Win32.Foundation.PSTR) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpOidCopy(srcOID: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID), dstOID: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpOidCompare(xOID: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID), yOID: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOID), maxlen: UInt32, result: POINTER(Int32)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpEncodeMsg(session: IntPtr, srcEntity: IntPtr, dstEntity: IntPtr, context: IntPtr, pdu: IntPtr, msgBufDesc: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOCTETS)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpDecodeMsg(session: IntPtr, srcEntity: POINTER(IntPtr), dstEntity: POINTER(IntPtr), context: POINTER(IntPtr), pdu: POINTER(IntPtr), msgBufDesc: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOCTETS)) -> UInt32: ...
@winfunctype('wsnmp32.dll')
def SnmpFreeDescriptor(syntax: UInt32, descriptor: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.smiOCTETS)) -> UInt32: ...
class AsnAny(Structure):
    asnType: Byte
    asnValue: _asnValue_e__Union
    _pack_ = 4
    class _asnValue_e__Union(Union):
        number: Int32
        unsigned32: UInt32
        counter64: UInt64
        string: win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString
        bits: win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString
        object: win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier
        sequence: win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString
        address: win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString
        counter: UInt32
        gauge: UInt32
        ticks: UInt32
        arbitrary: win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString
        _pack_ = 4
if ARCH in 'X64,ARM64':
    class AsnObjectIdentifier(Structure):
        idLength: UInt32
        ids: POINTER(UInt32)
        _pack_ = 4
elif ARCH in 'X86':
    class AsnObjectIdentifier(Structure):
        idLength: UInt32
        ids: POINTER(UInt32)
if ARCH in 'X64,ARM64':
    class AsnOctetString(Structure):
        stream: POINTER(Byte)
        length: UInt32
        dynamic: win32more.Windows.Win32.Foundation.BOOL
        _pack_ = 4
elif ARCH in 'X86':
    class AsnOctetString(Structure):
        stream: POINTER(Byte)
        length: UInt32
        dynamic: win32more.Windows.Win32.Foundation.BOOL
@winfunctype_pointer
def PFNSNMPCLEANUPEX() -> UInt32: ...
@winfunctype_pointer
def PFNSNMPEXTENSIONCLOSE() -> Void: ...
@winfunctype_pointer
def PFNSNMPEXTENSIONINIT(dwUpTimeReference: UInt32, phSubagentTrapEvent: POINTER(win32more.Windows.Win32.Foundation.HANDLE), pFirstSupportedRegion: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFNSNMPEXTENSIONINITEX(pNextSupportedRegion: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFNSNMPEXTENSIONMONITOR(pAgentMgmtData: VoidPtr) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFNSNMPEXTENSIONQUERY(bPduType: Byte, pVarBindList: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBindList), pErrorStatus: POINTER(Int32), pErrorIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFNSNMPEXTENSIONQUERYEX(nRequestType: UInt32, nTransactionId: UInt32, pVarBindList: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBindList), pContextInfo: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnOctetString), pErrorStatus: POINTER(Int32), pErrorIndex: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFNSNMPEXTENSIONTRAP(pEnterpriseOid: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier), pGenericTrapId: POINTER(Int32), pSpecificTrapId: POINTER(Int32), pTimeStamp: POINTER(UInt32), pVarBindList: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBindList)) -> win32more.Windows.Win32.Foundation.BOOL: ...
@winfunctype_pointer
def PFNSNMPSTARTUPEX(param0: POINTER(UInt32), param1: POINTER(UInt32), param2: POINTER(UInt32), param3: POINTER(UInt32), param4: POINTER(UInt32)) -> UInt32: ...
@winfunctype_pointer
def SNMPAPI_CALLBACK(hSession: IntPtr, hWnd: win32more.Windows.Win32.Foundation.HWND, wMsg: UInt32, wParam: win32more.Windows.Win32.Foundation.WPARAM, lParam: win32more.Windows.Win32.Foundation.LPARAM, lpClientData: VoidPtr) -> UInt32: ...
SNMP_API_TRANSLATE_MODE = UInt32
SNMPAPI_TRANSLATED: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_API_TRANSLATE_MODE = 0
SNMPAPI_UNTRANSLATED_V1: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_API_TRANSLATE_MODE = 1
SNMPAPI_UNTRANSLATED_V2: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_API_TRANSLATE_MODE = 2
SNMP_ERROR = UInt32
SNMP_ERROR_NOERROR: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 0
SNMP_ERROR_TOOBIG: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 1
SNMP_ERROR_NOSUCHNAME: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 2
SNMP_ERROR_BADVALUE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 3
SNMP_ERROR_READONLY: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 4
SNMP_ERROR_GENERR: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 5
SNMP_ERROR_NOACCESS: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 6
SNMP_ERROR_WRONGTYPE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 7
SNMP_ERROR_WRONGLENGTH: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 8
SNMP_ERROR_WRONGENCODING: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 9
SNMP_ERROR_WRONGVALUE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 10
SNMP_ERROR_NOCREATION: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 11
SNMP_ERROR_INCONSISTENTVALUE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 12
SNMP_ERROR_RESOURCEUNAVAILABLE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 13
SNMP_ERROR_COMMITFAILED: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 14
SNMP_ERROR_UNDOFAILED: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 15
SNMP_ERROR_AUTHORIZATIONERROR: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 16
SNMP_ERROR_NOTWRITABLE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 17
SNMP_ERROR_INCONSISTENTNAME: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR = 18
SNMP_ERROR_STATUS = UInt32
SNMP_ERRORSTATUS_NOERROR: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 0
SNMP_ERRORSTATUS_TOOBIG: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 1
SNMP_ERRORSTATUS_NOSUCHNAME: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 2
SNMP_ERRORSTATUS_BADVALUE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 3
SNMP_ERRORSTATUS_READONLY: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 4
SNMP_ERRORSTATUS_GENERR: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 5
SNMP_ERRORSTATUS_NOACCESS: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 6
SNMP_ERRORSTATUS_WRONGTYPE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 7
SNMP_ERRORSTATUS_WRONGLENGTH: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 8
SNMP_ERRORSTATUS_WRONGENCODING: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 9
SNMP_ERRORSTATUS_WRONGVALUE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 10
SNMP_ERRORSTATUS_NOCREATION: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 11
SNMP_ERRORSTATUS_INCONSISTENTVALUE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 12
SNMP_ERRORSTATUS_RESOURCEUNAVAILABLE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 13
SNMP_ERRORSTATUS_COMMITFAILED: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 14
SNMP_ERRORSTATUS_UNDOFAILED: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 15
SNMP_ERRORSTATUS_AUTHORIZATIONERROR: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 16
SNMP_ERRORSTATUS_NOTWRITABLE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 17
SNMP_ERRORSTATUS_INCONSISTENTNAME: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_ERROR_STATUS = 18
SNMP_EXTENSION_REQUEST_TYPE = UInt32
SNMP_EXTENSION_GET: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_EXTENSION_REQUEST_TYPE = 160
SNMP_EXTENSION_GET_NEXT: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_EXTENSION_REQUEST_TYPE = 161
SNMP_EXTENSION_SET_TEST: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_EXTENSION_REQUEST_TYPE = 224
SNMP_EXTENSION_SET_COMMIT: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_EXTENSION_REQUEST_TYPE = 163
SNMP_EXTENSION_SET_UNDO: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_EXTENSION_REQUEST_TYPE = 225
SNMP_EXTENSION_SET_CLEANUP: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_EXTENSION_REQUEST_TYPE = 226
SNMP_GENERICTRAP = UInt32
SNMP_GENERICTRAP_COLDSTART: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_GENERICTRAP = 0
SNMP_GENERICTRAP_WARMSTART: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_GENERICTRAP = 1
SNMP_GENERICTRAP_LINKDOWN: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_GENERICTRAP = 2
SNMP_GENERICTRAP_LINKUP: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_GENERICTRAP = 3
SNMP_GENERICTRAP_AUTHFAILURE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_GENERICTRAP = 4
SNMP_GENERICTRAP_EGPNEIGHLOSS: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_GENERICTRAP = 5
SNMP_GENERICTRAP_ENTERSPECIFIC: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_GENERICTRAP = 6
SNMP_LOG = Int32
SNMP_LOG_SILENT: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_LOG = 0
SNMP_LOG_FATAL: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_LOG = 1
SNMP_LOG_ERROR: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_LOG = 2
SNMP_LOG_WARNING: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_LOG = 3
SNMP_LOG_TRACE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_LOG = 4
SNMP_LOG_VERBOSE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_LOG = 5
SNMP_OUTPUT_LOG_TYPE = UInt32
SNMP_OUTPUT_TO_CONSOLE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_OUTPUT_LOG_TYPE = 1
SNMP_OUTPUT_TO_LOGFILE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_OUTPUT_LOG_TYPE = 2
SNMP_OUTPUT_TO_DEBUGGER: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_OUTPUT_LOG_TYPE = 8
SNMP_PDU_TYPE = UInt32
SNMP_PDU_GET: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_PDU_TYPE = 160
SNMP_PDU_GETNEXT: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_PDU_TYPE = 161
SNMP_PDU_RESPONSE: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_PDU_TYPE = 162
SNMP_PDU_SET: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_PDU_TYPE = 163
SNMP_PDU_GETBULK: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_PDU_TYPE = 165
SNMP_PDU_TRAP: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_PDU_TYPE = 167
SNMP_STATUS = UInt32
SNMPAPI_ON: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_STATUS = 1
SNMPAPI_OFF: win32more.Windows.Win32.NetworkManagement.Snmp.SNMP_STATUS = 0
class SnmpVarBind(Structure):
    name: win32more.Windows.Win32.NetworkManagement.Snmp.AsnObjectIdentifier
    value: win32more.Windows.Win32.NetworkManagement.Snmp.AsnAny
    _pack_ = 4
if ARCH in 'X64,ARM64':
    class SnmpVarBindList(Structure):
        list: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBind)
        len: UInt32
        _pack_ = 4
elif ARCH in 'X86':
    class SnmpVarBindList(Structure):
        list: POINTER(win32more.Windows.Win32.NetworkManagement.Snmp.SnmpVarBind)
        len: UInt32
class smiCNTR64(Structure):
    hipart: UInt32
    lopart: UInt32
class smiOCTETS(Structure):
    len: UInt32
    ptr: POINTER(Byte)
class smiOID(Structure):
    len: UInt32
    ptr: POINTER(UInt32)
class smiVALUE(Structure):
    syntax: UInt32
    value: _value_e__Union
    class _value_e__Union(Union):
        sNumber: Int32
        uNumber: UInt32
        hNumber: win32more.Windows.Win32.NetworkManagement.Snmp.smiCNTR64
        string: win32more.Windows.Win32.NetworkManagement.Snmp.smiOCTETS
        oid: win32more.Windows.Win32.NetworkManagement.Snmp.smiOID
        empty: Byte
class smiVENDORINFO(Structure):
    vendorName: win32more.Windows.Win32.Foundation.CHAR * 64
    vendorContact: win32more.Windows.Win32.Foundation.CHAR * 64
    vendorVersionId: win32more.Windows.Win32.Foundation.CHAR * 32
    vendorVersionDate: win32more.Windows.Win32.Foundation.CHAR * 32
    vendorEnterprise: UInt32


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Adc.Provider
import win32more.Windows.Foundation.Collections
import win32more.Windows.Win32.System.WinRT
class IAdcControllerProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Adc.Provider.IAdcControllerProvider'
    _iid_ = Guid('{be545828-816d-4de5-a048-aba06958aaa8}')
    @winrt_commethod(6)
    def get_ChannelCount(self) -> Int32: ...
    @winrt_commethod(7)
    def get_ResolutionInBits(self) -> Int32: ...
    @winrt_commethod(8)
    def get_MinValue(self) -> Int32: ...
    @winrt_commethod(9)
    def get_MaxValue(self) -> Int32: ...
    @winrt_commethod(10)
    def get_ChannelMode(self) -> win32more.Windows.Devices.Adc.Provider.ProviderAdcChannelMode: ...
    @winrt_commethod(11)
    def put_ChannelMode(self, value: win32more.Windows.Devices.Adc.Provider.ProviderAdcChannelMode) -> Void: ...
    @winrt_commethod(12)
    def IsChannelModeSupported(self, channelMode: win32more.Windows.Devices.Adc.Provider.ProviderAdcChannelMode) -> Boolean: ...
    @winrt_commethod(13)
    def AcquireChannel(self, channel: Int32) -> Void: ...
    @winrt_commethod(14)
    def ReleaseChannel(self, channel: Int32) -> Void: ...
    @winrt_commethod(15)
    def ReadValue(self, channelNumber: Int32) -> Int32: ...
    ChannelCount = property(get_ChannelCount, None)
    ChannelMode = property(get_ChannelMode, put_ChannelMode)
    MaxValue = property(get_MaxValue, None)
    MinValue = property(get_MinValue, None)
    ResolutionInBits = property(get_ResolutionInBits, None)
class IAdcProvider(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Devices.Adc.Provider.IAdcProvider'
    _iid_ = Guid('{28953668-9359-4c57-bc88-e275e81638c9}')
    @winrt_commethod(6)
    def GetControllers(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Adc.Provider.IAdcControllerProvider]: ...
class ProviderAdcChannelMode(Enum, Int32):
    SingleEnded = 0
    Differential = 1


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Networking.RemoteDifferentialCompression
import win32more.Windows.Win32.System.Com
RDCE_TABLE_FULL: UInt32 = 2147745793
RDCE_TABLE_CORRUPT: UInt32 = 2147745794
MSRDC_SIGNATURE_HASHSIZE: UInt32 = 16
SimilarityFileIdMinSize: UInt32 = 4
SimilarityFileIdMaxSize: UInt32 = 32
MSRDC_VERSION: UInt32 = 65536
MSRDC_MINIMUM_COMPATIBLE_APP_VERSION: UInt32 = 65536
MSRDC_MINIMUM_DEPTH: UInt32 = 1
MSRDC_MAXIMUM_DEPTH: UInt32 = 8
MSRDC_MINIMUM_COMPAREBUFFER: UInt32 = 100000
MSRDC_MAXIMUM_COMPAREBUFFER: UInt32 = 1073741824
MSRDC_DEFAULT_COMPAREBUFFER: UInt32 = 3200000
MSRDC_MINIMUM_INPUTBUFFERSIZE: UInt32 = 1024
MSRDC_MINIMUM_HORIZONSIZE: UInt32 = 128
MSRDC_MAXIMUM_HORIZONSIZE: UInt32 = 16384
MSRDC_MINIMUM_HASHWINDOWSIZE: UInt32 = 2
MSRDC_MAXIMUM_HASHWINDOWSIZE: UInt32 = 96
MSRDC_DEFAULT_HASHWINDOWSIZE_1: UInt32 = 48
MSRDC_DEFAULT_HORIZONSIZE_1: UInt32 = 1024
MSRDC_DEFAULT_HASHWINDOWSIZE_N: UInt32 = 2
MSRDC_DEFAULT_HORIZONSIZE_N: UInt32 = 128
MSRDC_MAXIMUM_TRAITVALUE: UInt32 = 63
MSRDC_MINIMUM_MATCHESREQUIRED: UInt32 = 1
MSRDC_MAXIMUM_MATCHESREQUIRED: UInt32 = 16
class FindSimilarFileIndexResults(Structure):
    m_FileIndex: UInt32
    m_MatchCount: UInt32
FindSimilarResults = Guid('{96236a93-9dbc-11da-9e3f-0011114ae311}')
GeneratorParametersType = Int32
RDCGENTYPE_Unused: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.GeneratorParametersType = 0
RDCGENTYPE_FilterMax: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.GeneratorParametersType = 1
class IFindSimilarResults(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a81-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def GetSize(self, size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetNextFileId(self, numTraitsMatched: POINTER(UInt32), similarityFileId: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityFileId)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRdcComparator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a77-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def Process(self, endOfInput: win32more.Windows.Win32.Foundation.BOOL, endOfOutput: POINTER(win32more.Windows.Win32.Foundation.BOOL), inputBuffer: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcBufferPointer), outputBuffer: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcNeedPointer), rdc_ErrorCode: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRdcFileReader(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a74-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def GetFileSize(self, fileSize: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Read(self, offsetFileStart: UInt64, bytesToRead: UInt32, bytesActuallyRead: POINTER(UInt32), buffer: POINTER(Byte), eof: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFilePosition(self, offsetFromStart: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRdcFileWriter(ComPtr):
    extends: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcFileReader
    _iid_ = Guid('{96236a75-9dbc-11da-9e3f-0011114ae311}')
    @commethod(6)
    def Write(self, offsetFileStart: UInt64, bytesToWrite: UInt32, buffer: POINTER(Byte)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Truncate(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def DeleteOnClose(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRdcGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a73-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def GetGeneratorParameters(self, level: UInt32, iGeneratorParameters: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcGeneratorParameters)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Process(self, endOfInput: win32more.Windows.Win32.Foundation.BOOL, endOfOutput: POINTER(win32more.Windows.Win32.Foundation.BOOL), inputBuffer: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcBufferPointer), depth: UInt32, outputBuffers: POINTER(POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcBufferPointer)), rdc_ErrorCode: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRdcGeneratorFilterMaxParameters(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a72-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def GetHorizonSize(self, horizonSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetHorizonSize(self, horizonSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetHashWindowSize(self, hashWindowSize: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetHashWindowSize(self, hashWindowSize: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRdcGeneratorParameters(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a71-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def GetGeneratorParametersType(self, parametersType: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.GeneratorParametersType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetParametersVersion(self, currentVersion: POINTER(UInt32), minimumCompatibleAppVersion: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSerializeSize(self, size: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Serialize(self, size: UInt32, parametersBlob: POINTER(Byte), bytesWritten: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRdcLibrary(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a78-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def ComputeDefaultRecursionDepth(self, fileSize: UInt64, depth: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateGeneratorParameters(self, parametersType: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.GeneratorParametersType, level: UInt32, iGeneratorParameters: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcGeneratorParameters)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def OpenGeneratorParameters(self, size: UInt32, parametersBlob: POINTER(Byte), iGeneratorParameters: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcGeneratorParameters)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreateGenerator(self, depth: UInt32, iGeneratorParametersArray: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcGeneratorParameters), iGenerator: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcGenerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateComparator(self, iSeedSignaturesFile: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcFileReader, comparatorBufferSize: UInt32, iComparator: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcComparator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CreateSignatureReader(self, iFileReader: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcFileReader, iSignatureReader: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcSignatureReader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRDCVersion(self, currentVersion: POINTER(UInt32), minimumCompatibleAppVersion: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRdcSignatureReader(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a76-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def ReadHeader(self, rdc_ErrorCode: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def ReadSignatures(self, rdcSignaturePointer: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcSignaturePointer), endOfOutput: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IRdcSimilarityGenerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a80-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def EnableSimilarity(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Results(self, similarityData: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityData)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISimilarity(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a83-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def CreateTable(self, path: win32more.Windows.Win32.Foundation.PWSTR, truncate: win32more.Windows.Win32.Foundation.BOOL, securityDescriptor: POINTER(Byte), recordSize: UInt32, isNew: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcCreatedTables)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateTableIndirect(self, mapping: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.ISimilarityTraitsMapping, fileIdFile: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcFileWriter, truncate: win32more.Windows.Win32.Foundation.BOOL, recordSize: UInt32, isNew: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcCreatedTables)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CloseTable(self, isValid: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Append(self, similarityFileId: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityFileId), similarityData: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityData)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindSimilarFileId(self, similarityData: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityData), numberOfMatchesRequired: UInt16, resultsSize: UInt32, findSimilarResults: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IFindSimilarResults)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def CopyAndSwap(self, newSimilarityTables: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.ISimilarity, reportProgress: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.ISimilarityReportProgress) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRecordCount(self, recordCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISimilarityFileIdTable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a7f-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def CreateTable(self, path: win32more.Windows.Win32.Foundation.PWSTR, truncate: win32more.Windows.Win32.Foundation.BOOL, securityDescriptor: POINTER(Byte), recordSize: UInt32, isNew: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcCreatedTables)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateTableIndirect(self, fileIdFile: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.IRdcFileWriter, truncate: win32more.Windows.Win32.Foundation.BOOL, recordSize: UInt32, isNew: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcCreatedTables)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CloseTable(self, isValid: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Append(self, similarityFileId: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityFileId), similarityFileIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def Lookup(self, similarityFileIndex: UInt32, similarityFileId: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityFileId)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Invalidate(self, similarityFileIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRecordCount(self, recordCount: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISimilarityReportProgress(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a7a-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def ReportProgress(self, percentCompleted: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISimilarityTableDumpState(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a7b-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def GetNextData(self, resultsSize: UInt32, resultsUsed: POINTER(UInt32), eof: POINTER(win32more.Windows.Win32.Foundation.BOOL), results: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityDumpData)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISimilarityTraitsMappedView(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a7c-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def Flush(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Unmap(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Get(self, index: UInt64, dirty: win32more.Windows.Win32.Foundation.BOOL, numElements: UInt32, viewInfo: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityMappedViewInfo)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetView(self, mappedPageBegin: POINTER(POINTER(Byte)), mappedPageEnd: POINTER(POINTER(Byte))) -> Void: ...
class ISimilarityTraitsMapping(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a7d-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def CloseMapping(self) -> Void: ...
    @commethod(4)
    def SetFileSize(self, fileSize: UInt64) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetFileSize(self, fileSize: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def OpenMapping(self, accessMode: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcMappingAccessMode, begin: UInt64, end: UInt64, actualEnd: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ResizeMapping(self, accessMode: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcMappingAccessMode, begin: UInt64, end: UInt64, actualEnd: POINTER(UInt64)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetPageSize(self, pageSize: POINTER(UInt32)) -> Void: ...
    @commethod(9)
    def CreateView(self, minimumMappedPages: UInt32, accessMode: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcMappingAccessMode, mappedView: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.ISimilarityTraitsMappedView)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISimilarityTraitsTable(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{96236a7e-9dbc-11da-9e3f-0011114ae311}')
    @commethod(3)
    def CreateTable(self, path: win32more.Windows.Win32.Foundation.PWSTR, truncate: win32more.Windows.Win32.Foundation.BOOL, securityDescriptor: POINTER(Byte), isNew: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcCreatedTables)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateTableIndirect(self, mapping: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.ISimilarityTraitsMapping, truncate: win32more.Windows.Win32.Foundation.BOOL, isNew: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcCreatedTables)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CloseTable(self, isValid: win32more.Windows.Win32.Foundation.BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Append(self, data: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityData), fileIndex: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def FindSimilarFileIndex(self, similarityData: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityData), numberOfMatchesRequired: UInt16, findSimilarFileIndexResults: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.FindSimilarFileIndexResults), resultsSize: UInt32, resultsUsed: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def BeginDump(self, similarityTableDumpState: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.ISimilarityTableDumpState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetLastIndex(self, fileIndex: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
RDC_ErrorCode = Int32
RDC_NoError: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 0
RDC_HeaderVersionNewer: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 1
RDC_HeaderVersionOlder: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 2
RDC_HeaderMissingOrCorrupt: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 3
RDC_HeaderWrongType: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 4
RDC_DataMissingOrCorrupt: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 5
RDC_DataTooManyRecords: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 6
RDC_FileChecksumMismatch: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 7
RDC_ApplicationError: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 8
RDC_Aborted: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 9
RDC_Win32Error: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RDC_ErrorCode = 10
class RdcBufferPointer(Structure):
    m_Size: UInt32
    m_Used: UInt32
    m_Data: POINTER(Byte)
RdcComparator = Guid('{96236a8b-9dbc-11da-9e3f-0011114ae311}')
RdcCreatedTables = Int32
RDCTABLE_InvalidOrUnknown: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcCreatedTables = 0
RDCTABLE_Existing: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcCreatedTables = 1
RDCTABLE_New: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcCreatedTables = 2
RdcFileReader = Guid('{96236a89-9dbc-11da-9e3f-0011114ae311}')
RdcGenerator = Guid('{96236a88-9dbc-11da-9e3f-0011114ae311}')
RdcGeneratorFilterMaxParameters = Guid('{96236a87-9dbc-11da-9e3f-0011114ae311}')
RdcGeneratorParameters = Guid('{96236a86-9dbc-11da-9e3f-0011114ae311}')
RdcLibrary = Guid('{96236a85-9dbc-11da-9e3f-0011114ae311}')
RdcMappingAccessMode = Int32
RDCMAPPING_Undefined: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcMappingAccessMode = 0
RDCMAPPING_ReadOnly: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcMappingAccessMode = 1
RDCMAPPING_ReadWrite: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcMappingAccessMode = 2
class RdcNeed(Structure):
    m_BlockType: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcNeedType
    m_FileOffset: UInt64
    m_BlockLength: UInt64
class RdcNeedPointer(Structure):
    m_Size: UInt32
    m_Used: UInt32
    m_Data: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcNeed)
RdcNeedType = Int32
RDCNEED_SOURCE: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcNeedType = 0
RDCNEED_TARGET: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcNeedType = 1
RDCNEED_SEED: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcNeedType = 2
RDCNEED_SEED_MAX: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcNeedType = 255
class RdcSignature(Structure):
    m_Signature: Byte * 16
    m_BlockLength: UInt16
class RdcSignaturePointer(Structure):
    m_Size: UInt32
    m_Used: UInt32
    m_Data: POINTER(win32more.Windows.Win32.Networking.RemoteDifferentialCompression.RdcSignature)
RdcSignatureReader = Guid('{96236a8a-9dbc-11da-9e3f-0011114ae311}')
RdcSimilarityGenerator = Guid('{96236a92-9dbc-11da-9e3f-0011114ae311}')
Similarity = Guid('{96236a91-9dbc-11da-9e3f-0011114ae311}')
class SimilarityData(Structure):
    m_Data: Byte * 16
class SimilarityDumpData(Structure):
    m_FileIndex: UInt32
    m_Data: win32more.Windows.Win32.Networking.RemoteDifferentialCompression.SimilarityData
class SimilarityFileId(Structure):
    m_FileId: Byte * 32
SimilarityFileIdTable = Guid('{96236a90-9dbc-11da-9e3f-0011114ae311}')
class SimilarityMappedViewInfo(Structure):
    m_Data: POINTER(Byte)
    m_Length: UInt32
SimilarityReportProgress = Guid('{96236a8d-9dbc-11da-9e3f-0011114ae311}')
SimilarityTableDumpState = Guid('{96236a8e-9dbc-11da-9e3f-0011114ae311}')
SimilarityTraitsMappedView = Guid('{96236a95-9dbc-11da-9e3f-0011114ae311}')
SimilarityTraitsMapping = Guid('{96236a94-9dbc-11da-9e3f-0011114ae311}')
SimilarityTraitsTable = Guid('{96236a8f-9dbc-11da-9e3f-0011114ae311}')


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.Security
import win32more.Windows.Win32.Security.Cryptography
import win32more.Windows.Win32.Storage.Packaging.Opc
import win32more.Windows.Win32.System.Com
OPC_E_NONCONFORMING_URI: win32more.Windows.Win32.Foundation.HRESULT = -2142175231
OPC_E_RELATIVE_URI_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2142175230
OPC_E_RELATIONSHIP_URI_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2142175229
OPC_E_PART_CANNOT_BE_DIRECTORY: win32more.Windows.Win32.Foundation.HRESULT = -2142175228
OPC_E_UNEXPECTED_CONTENT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2142175227
OPC_E_INVALID_CONTENT_TYPE_XML: win32more.Windows.Win32.Foundation.HRESULT = -2142175226
OPC_E_MISSING_CONTENT_TYPES: win32more.Windows.Win32.Foundation.HRESULT = -2142175225
OPC_E_NONCONFORMING_CONTENT_TYPES_XML: win32more.Windows.Win32.Foundation.HRESULT = -2142175224
OPC_E_NONCONFORMING_RELS_XML: win32more.Windows.Win32.Foundation.HRESULT = -2142175223
OPC_E_INVALID_RELS_XML: win32more.Windows.Win32.Foundation.HRESULT = -2142175222
OPC_E_DUPLICATE_PART: win32more.Windows.Win32.Foundation.HRESULT = -2142175221
OPC_E_INVALID_OVERRIDE_PART_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2142175220
OPC_E_DUPLICATE_OVERRIDE_PART: win32more.Windows.Win32.Foundation.HRESULT = -2142175219
OPC_E_INVALID_DEFAULT_EXTENSION: win32more.Windows.Win32.Foundation.HRESULT = -2142175218
OPC_E_DUPLICATE_DEFAULT_EXTENSION: win32more.Windows.Win32.Foundation.HRESULT = -2142175217
OPC_E_INVALID_RELATIONSHIP_ID: win32more.Windows.Win32.Foundation.HRESULT = -2142175216
OPC_E_INVALID_RELATIONSHIP_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2142175215
OPC_E_INVALID_RELATIONSHIP_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2142175214
OPC_E_DUPLICATE_RELATIONSHIP: win32more.Windows.Win32.Foundation.HRESULT = -2142175213
OPC_E_CONFLICTING_SETTINGS: win32more.Windows.Win32.Foundation.HRESULT = -2142175212
OPC_E_DUPLICATE_PIECE: win32more.Windows.Win32.Foundation.HRESULT = -2142175211
OPC_E_INVALID_PIECE: win32more.Windows.Win32.Foundation.HRESULT = -2142175210
OPC_E_MISSING_PIECE: win32more.Windows.Win32.Foundation.HRESULT = -2142175209
OPC_E_NO_SUCH_PART: win32more.Windows.Win32.Foundation.HRESULT = -2142175208
OPC_E_DS_SIGNATURE_CORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2142175207
OPC_E_DS_DIGEST_VALUE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2142175206
OPC_E_DS_DUPLICATE_SIGNATURE_ORIGIN_RELATIONSHIP: win32more.Windows.Win32.Foundation.HRESULT = -2142175205
OPC_E_DS_INVALID_SIGNATURE_ORIGIN_RELATIONSHIP: win32more.Windows.Win32.Foundation.HRESULT = -2142175204
OPC_E_DS_INVALID_CERTIFICATE_RELATIONSHIP: win32more.Windows.Win32.Foundation.HRESULT = -2142175203
OPC_E_DS_EXTERNAL_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2142175202
OPC_E_DS_MISSING_SIGNATURE_ORIGIN_PART: win32more.Windows.Win32.Foundation.HRESULT = -2142175201
OPC_E_DS_MISSING_SIGNATURE_PART: win32more.Windows.Win32.Foundation.HRESULT = -2142175200
OPC_E_DS_INVALID_RELATIONSHIP_TRANSFORM_XML: win32more.Windows.Win32.Foundation.HRESULT = -2142175199
OPC_E_DS_INVALID_CANONICALIZATION_METHOD: win32more.Windows.Win32.Foundation.HRESULT = -2142175198
OPC_E_DS_INVALID_RELATIONSHIPS_SIGNING_OPTION: win32more.Windows.Win32.Foundation.HRESULT = -2142175197
OPC_E_DS_INVALID_OPC_SIGNATURE_TIME_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2142175196
OPC_E_DS_PACKAGE_REFERENCE_URI_RESERVED: win32more.Windows.Win32.Foundation.HRESULT = -2142175195
OPC_E_DS_MISSING_SIGNATURE_PROPERTIES_ELEMENT: win32more.Windows.Win32.Foundation.HRESULT = -2142175194
OPC_E_DS_MISSING_SIGNATURE_PROPERTY_ELEMENT: win32more.Windows.Win32.Foundation.HRESULT = -2142175193
OPC_E_DS_DUPLICATE_SIGNATURE_PROPERTY_ELEMENT: win32more.Windows.Win32.Foundation.HRESULT = -2142175192
OPC_E_DS_MISSING_SIGNATURE_TIME_PROPERTY: win32more.Windows.Win32.Foundation.HRESULT = -2142175191
OPC_E_DS_INVALID_SIGNATURE_XML: win32more.Windows.Win32.Foundation.HRESULT = -2142175190
OPC_E_DS_INVALID_SIGNATURE_COUNT: win32more.Windows.Win32.Foundation.HRESULT = -2142175189
OPC_E_DS_MISSING_SIGNATURE_ALGORITHM: win32more.Windows.Win32.Foundation.HRESULT = -2142175188
OPC_E_DS_DUPLICATE_PACKAGE_OBJECT_REFERENCES: win32more.Windows.Win32.Foundation.HRESULT = -2142175187
OPC_E_DS_MISSING_PACKAGE_OBJECT_REFERENCE: win32more.Windows.Win32.Foundation.HRESULT = -2142175186
OPC_E_DS_EXTERNAL_SIGNATURE_REFERENCE: win32more.Windows.Win32.Foundation.HRESULT = -2142175185
OPC_E_DS_REFERENCE_MISSING_CONTENT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2142175184
OPC_E_DS_MULTIPLE_RELATIONSHIP_TRANSFORMS: win32more.Windows.Win32.Foundation.HRESULT = -2142175183
OPC_E_DS_MISSING_CANONICALIZATION_TRANSFORM: win32more.Windows.Win32.Foundation.HRESULT = -2142175182
OPC_E_MC_UNEXPECTED_ELEMENT: win32more.Windows.Win32.Foundation.HRESULT = -2142175181
OPC_E_MC_UNEXPECTED_REQUIRES_ATTR: win32more.Windows.Win32.Foundation.HRESULT = -2142175180
OPC_E_MC_MISSING_REQUIRES_ATTR: win32more.Windows.Win32.Foundation.HRESULT = -2142175179
OPC_E_MC_UNEXPECTED_ATTR: win32more.Windows.Win32.Foundation.HRESULT = -2142175178
OPC_E_MC_INVALID_PREFIX_LIST: win32more.Windows.Win32.Foundation.HRESULT = -2142175177
OPC_E_MC_INVALID_QNAME_LIST: win32more.Windows.Win32.Foundation.HRESULT = -2142175176
OPC_E_MC_NESTED_ALTERNATE_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -2142175175
OPC_E_MC_UNEXPECTED_CHOICE: win32more.Windows.Win32.Foundation.HRESULT = -2142175174
OPC_E_MC_MISSING_CHOICE: win32more.Windows.Win32.Foundation.HRESULT = -2142175173
OPC_E_MC_INVALID_ENUM_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2142175172
OPC_E_MC_UNKNOWN_NAMESPACE: win32more.Windows.Win32.Foundation.HRESULT = -2142175170
OPC_E_MC_UNKNOWN_PREFIX: win32more.Windows.Win32.Foundation.HRESULT = -2142175169
OPC_E_MC_INVALID_ATTRIBUTES_ON_IGNORABLE_ELEMENT: win32more.Windows.Win32.Foundation.HRESULT = -2142175168
OPC_E_MC_INVALID_XMLNS_ATTRIBUTE: win32more.Windows.Win32.Foundation.HRESULT = -2142175167
OPC_E_INVALID_XML_ENCODING: win32more.Windows.Win32.Foundation.HRESULT = -2142175166
OPC_E_DS_SIGNATURE_REFERENCE_MISSING_URI: win32more.Windows.Win32.Foundation.HRESULT = -2142175165
OPC_E_INVALID_CONTENT_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2142175164
OPC_E_DS_SIGNATURE_PROPERTY_MISSING_TARGET: win32more.Windows.Win32.Foundation.HRESULT = -2142175163
OPC_E_DS_SIGNATURE_METHOD_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2142175162
OPC_E_DS_DEFAULT_DIGEST_METHOD_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2142175161
OPC_E_NO_SUCH_RELATIONSHIP: win32more.Windows.Win32.Foundation.HRESULT = -2142175160
OPC_E_MC_MULTIPLE_FALLBACK_ELEMENTS: win32more.Windows.Win32.Foundation.HRESULT = -2142175159
OPC_E_MC_INCONSISTENT_PROCESS_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -2142175158
OPC_E_MC_INCONSISTENT_PRESERVE_ATTRIBUTES: win32more.Windows.Win32.Foundation.HRESULT = -2142175157
OPC_E_MC_INCONSISTENT_PRESERVE_ELEMENTS: win32more.Windows.Win32.Foundation.HRESULT = -2142175156
OPC_E_INVALID_RELATIONSHIP_TARGET_MODE: win32more.Windows.Win32.Foundation.HRESULT = -2142175155
OPC_E_COULD_NOT_RECOVER: win32more.Windows.Win32.Foundation.HRESULT = -2142175154
OPC_E_UNSUPPORTED_PACKAGE: win32more.Windows.Win32.Foundation.HRESULT = -2142175153
OPC_E_ENUM_COLLECTION_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -2142175152
OPC_E_ENUM_CANNOT_MOVE_NEXT: win32more.Windows.Win32.Foundation.HRESULT = -2142175151
OPC_E_ENUM_CANNOT_MOVE_PREVIOUS: win32more.Windows.Win32.Foundation.HRESULT = -2142175150
OPC_E_ENUM_INVALID_POSITION: win32more.Windows.Win32.Foundation.HRESULT = -2142175149
OPC_E_DS_SIGNATURE_ORIGIN_EXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2142175148
OPC_E_DS_UNSIGNED_PACKAGE: win32more.Windows.Win32.Foundation.HRESULT = -2142175147
OPC_E_DS_MISSING_CERTIFICATE_PART: win32more.Windows.Win32.Foundation.HRESULT = -2142175146
OPC_E_NO_SUCH_SETTINGS: win32more.Windows.Win32.Foundation.HRESULT = -2142175145
OPC_E_ZIP_INCORRECT_DATA_SIZE: win32more.Windows.Win32.Foundation.HRESULT = -2142171135
OPC_E_ZIP_CORRUPTED_ARCHIVE: win32more.Windows.Win32.Foundation.HRESULT = -2142171134
OPC_E_ZIP_COMPRESSION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2142171133
OPC_E_ZIP_DECOMPRESSION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2142171132
OPC_E_ZIP_INCONSISTENT_FILEITEM: win32more.Windows.Win32.Foundation.HRESULT = -2142171131
OPC_E_ZIP_INCONSISTENT_DIRECTORY: win32more.Windows.Win32.Foundation.HRESULT = -2142171130
OPC_E_ZIP_MISSING_DATA_DESCRIPTOR: win32more.Windows.Win32.Foundation.HRESULT = -2142171129
OPC_E_ZIP_UNSUPPORTEDARCHIVE: win32more.Windows.Win32.Foundation.HRESULT = -2142171128
OPC_E_ZIP_CENTRAL_DIRECTORY_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2142171127
OPC_E_ZIP_NAME_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2142171126
OPC_E_ZIP_DUPLICATE_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2142171125
OPC_E_ZIP_COMMENT_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2142171124
OPC_E_ZIP_EXTRA_FIELDS_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2142171123
OPC_E_ZIP_FILE_HEADER_TOO_LARGE: win32more.Windows.Win32.Foundation.HRESULT = -2142171122
OPC_E_ZIP_MISSING_END_OF_CENTRAL_DIRECTORY: win32more.Windows.Win32.Foundation.HRESULT = -2142171121
OPC_E_ZIP_REQUIRES_64_BIT: win32more.Windows.Win32.Foundation.HRESULT = -2142171120
class IOpcCertificateEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{85131937-8f24-421f-b439-59ab24d140b8}')
    @commethod(3)
    def MoveNext(self, hasNext: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MovePrevious(self, hasPrevious: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrent(self, certificate: POINTER(POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT))) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, copy: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcCertificateEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcCertificateSet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{56ea4325-8e2d-4167-b1a4-e486d24c8fa7}')
    @commethod(3)
    def Add(self, certificate: POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Remove(self, certificate: POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetEnumerator(self, certificateEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcCertificateEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcDigitalSignature(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{52ab21dd-1cd0-4949-bc80-0c1232d00cb4}')
    @commethod(3)
    def GetNamespaces(self, prefixes: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), namespaces: POINTER(POINTER(win32more.Windows.Win32.Foundation.PWSTR)), count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSignatureId(self, signatureId: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSignaturePartName(self, signaturePartName: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetSignatureMethod(self, signatureMethod: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCanonicalizationMethod(self, canonicalizationMethod: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetSignatureValue(self, signatureValue: POINTER(POINTER(Byte)), count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetSignaturePartReferenceEnumerator(self, partReferenceEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignaturePartReferenceEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetSignatureRelationshipReferenceEnumerator(self, relationshipReferenceEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureRelationshipReferenceEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetSigningTime(self, signingTime: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def GetTimeFormat(self, timeFormat: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_TIME_FORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetPackageObjectReference(self, packageObjectReference: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureReference)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetCertificateEnumerator(self, certificateEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcCertificateEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetCustomReferenceEnumerator(self, customReferenceEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureReferenceEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetCustomObjectEnumerator(self, customObjectEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureCustomObjectEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetSignatureXml(self, signatureXml: POINTER(POINTER(Byte)), count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcDigitalSignatureEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{967b6882-0ba3-4358-b9e7-b64c75063c5e}')
    @commethod(3)
    def MoveNext(self, hasNext: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MovePrevious(self, hasPrevious: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrent(self, digitalSignature: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcDigitalSignature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, copy: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcDigitalSignatureEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcDigitalSignatureManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{d5e62a0b-696d-462f-94df-72e33cef2659}')
    @commethod(3)
    def GetSignatureOriginPartName(self, signatureOriginPartName: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetSignatureOriginPartName(self, signatureOriginPartName: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSignatureEnumerator(self, signatureEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcDigitalSignatureEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def RemoveSignature(self, signaturePartName: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def CreateSigningOptions(self, signingOptions: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSigningOptions)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Validate(self, signature: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcDigitalSignature, certificate: POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT), validationResult: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_VALIDATION_RESULT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Sign(self, certificate: POINTER(win32more.Windows.Win32.Security.Cryptography.CERT_CONTEXT), signingOptions: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSigningOptions, digitalSignature: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcDigitalSignature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ReplaceSignatureXml(self, signaturePartName: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri, newSignatureXml: POINTER(Byte), count: UInt32, digitalSignature: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcDigitalSignature)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcFactory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6d0b4446-cd73-4ab3-94f4-8ccdf6116154}')
    @commethod(3)
    def CreatePackageRootUri(self, rootUri: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreatePartUri(self, pwzUri: win32more.Windows.Win32.Foundation.PWSTR, partUri: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def CreateStreamOnFile(self, filename: win32more.Windows.Win32.Foundation.PWSTR, ioMode: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_STREAM_IO_MODE, securityAttributes: POINTER(win32more.Windows.Win32.Security.SECURITY_ATTRIBUTES), dwFlagsAndAttributes: UInt32, stream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def CreatePackage(self, package: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPackage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def ReadPackageFromStream(self, stream: win32more.Windows.Win32.System.Com.IStream, flags: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_READ_FLAGS, package: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPackage)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def WritePackageToStream(self, package: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPackage, flags: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_WRITE_FLAGS, stream: win32more.Windows.Win32.System.Com.IStream) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CreateDigitalSignatureManager(self, package: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPackage, signatureManager: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcDigitalSignatureManager)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcPackage(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{42195949-3b79-4fc8-89c6-fc7fb979ee70}')
    @commethod(3)
    def GetPartSet(self, partSet: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartSet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetRelationshipSet(self, relationshipSet: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcPart(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{42195949-3b79-4fc8-89c6-fc7fb979ee71}')
    @commethod(3)
    def GetRelationshipSet(self, relationshipSet: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetContentStream(self, stream: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetName(self, name: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetContentType(self, contentType: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetCompressionOptions(self, compressionOptions: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_COMPRESSION_OPTIONS)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcPartEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{42195949-3b79-4fc8-89c6-fc7fb979ee75}')
    @commethod(3)
    def MoveNext(self, hasNext: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MovePrevious(self, hasPrevious: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrent(self, part: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPart)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, copy: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcPartSet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{42195949-3b79-4fc8-89c6-fc7fb979ee73}')
    @commethod(3)
    def GetPart(self, name: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri, part: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPart)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreatePart(self, name: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri, contentType: win32more.Windows.Win32.Foundation.PWSTR, compressionOptions: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_COMPRESSION_OPTIONS, part: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPart)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DeletePart(self, name: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def PartExists(self, name: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri, partExists: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetEnumerator(self, partEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcPartUri(ComPtr):
    extends: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcUri
    _iid_ = Guid('{7d3babe7-88b2-46ba-85cb-4203cb016c87}')
    @commethod(31)
    def ComparePartUri(self, partUri: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri, comparisonResult: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def GetSourceUri(self, sourceUri: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def IsRelationshipsPartUri(self, isRelationshipUri: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcRelationship(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{42195949-3b79-4fc8-89c6-fc7fb979ee72}')
    @commethod(3)
    def GetId(self, relationshipIdentifier: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetRelationshipType(self, relationshipType: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSourceUri(self, sourceUri: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetTargetUri(self, targetUri: POINTER(win32more.Windows.Win32.System.Com.IUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetTargetMode(self, targetMode: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_URI_TARGET_MODE)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcRelationshipEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{42195949-3b79-4fc8-89c6-fc7fb979ee76}')
    @commethod(3)
    def MoveNext(self, hasNext: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MovePrevious(self, hasPrevious: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrent(self, relationship: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationship)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, copy: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcRelationshipSelector(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f8f26c7f-b28f-4899-84c8-5d5639ede75f}')
    @commethod(3)
    def GetSelectorType(self, selector: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_RELATIONSHIP_SELECTOR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetSelectionCriterion(self, selectionCriterion: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcRelationshipSelectorEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5e50a181-a91b-48ac-88d2-bca3d8f8c0b1}')
    @commethod(3)
    def MoveNext(self, hasNext: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MovePrevious(self, hasPrevious: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrent(self, relationshipSelector: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSelector)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, copy: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSelectorEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcRelationshipSelectorSet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6e34c269-a4d3-47c0-b5c4-87ff2b3b6136}')
    @commethod(3)
    def Create(self, selector: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_RELATIONSHIP_SELECTOR, selectionCriterion: win32more.Windows.Win32.Foundation.PWSTR, relationshipSelector: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSelector)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Delete(self, relationshipSelector: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSelector) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetEnumerator(self, relationshipSelectorEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSelectorEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcRelationshipSet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{42195949-3b79-4fc8-89c6-fc7fb979ee74}')
    @commethod(3)
    def GetRelationship(self, relationshipIdentifier: win32more.Windows.Win32.Foundation.PWSTR, relationship: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationship)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateRelationship(self, relationshipIdentifier: win32more.Windows.Win32.Foundation.PWSTR, relationshipType: win32more.Windows.Win32.Foundation.PWSTR, targetUri: win32more.Windows.Win32.System.Com.IUri, targetMode: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_URI_TARGET_MODE, relationship: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationship)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def DeleteRelationship(self, relationshipIdentifier: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def RelationshipExists(self, relationshipIdentifier: win32more.Windows.Win32.Foundation.PWSTR, relationshipExists: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetEnumerator(self, relationshipEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetEnumeratorForType(self, relationshipType: win32more.Windows.Win32.Foundation.PWSTR, relationshipEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetRelationshipsContentStream(self, contents: POINTER(win32more.Windows.Win32.System.Com.IStream)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignatureCustomObject(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5d77a19e-62c1-44e7-becd-45da5ae51a56}')
    @commethod(3)
    def GetXml(self, xmlMarkup: POINTER(POINTER(Byte)), count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignatureCustomObjectEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{5ee4fe1d-e1b0-4683-8079-7ea0fcf80b4c}')
    @commethod(3)
    def MoveNext(self, hasNext: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MovePrevious(self, hasPrevious: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrent(self, customObject: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureCustomObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, copy: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureCustomObjectEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignatureCustomObjectSet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8f792ac5-7947-4e11-bc3d-2659ff046ae1}')
    @commethod(3)
    def Create(self, xmlMarkup: POINTER(Byte), count: UInt32, customObject: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureCustomObject)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Delete(self, customObject: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureCustomObject) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetEnumerator(self, customObjectEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureCustomObjectEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignaturePartReference(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e24231ca-59f4-484e-b64b-36eeda36072c}')
    @commethod(3)
    def GetPartName(self, partName: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetContentType(self, contentType: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDigestMethod(self, digestMethod: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetDigestValue(self, digestValue: POINTER(POINTER(Byte)), count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetTransformMethod(self, transformMethod: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignaturePartReferenceEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{80eb1561-8c77-49cf-8266-459b356ee99a}')
    @commethod(3)
    def MoveNext(self, hasNext: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MovePrevious(self, hasPrevious: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrent(self, partReference: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignaturePartReference)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, copy: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignaturePartReferenceEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignaturePartReferenceSet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{6c9fe28c-ecd9-4b22-9d36-7fdde670fec0}')
    @commethod(3)
    def Create(self, partUri: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri, digestMethod: win32more.Windows.Win32.Foundation.PWSTR, transformMethod: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD, partReference: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignaturePartReference)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Delete(self, partReference: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignaturePartReference) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetEnumerator(self, partReferenceEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignaturePartReferenceEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignatureReference(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{1b47005e-3011-4edc-be6f-0f65e5ab0342}')
    @commethod(3)
    def GetId(self, referenceId: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetUri(self, referenceUri: POINTER(win32more.Windows.Win32.System.Com.IUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetType(self, type: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetTransformMethod(self, transformMethod: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetDigestMethod(self, digestMethod: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetDigestValue(self, digestValue: POINTER(POINTER(Byte)), count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignatureReferenceEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{cfa59a45-28b1-4868-969e-fa8097fdc12a}')
    @commethod(3)
    def MoveNext(self, hasNext: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MovePrevious(self, hasPrevious: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrent(self, reference: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureReference)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, copy: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureReferenceEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignatureReferenceSet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{f3b02d31-ab12-42dd-9e2f-2b16761c3c1e}')
    @commethod(3)
    def Create(self, referenceUri: win32more.Windows.Win32.System.Com.IUri, referenceId: win32more.Windows.Win32.Foundation.PWSTR, type: win32more.Windows.Win32.Foundation.PWSTR, digestMethod: win32more.Windows.Win32.Foundation.PWSTR, transformMethod: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD, reference: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureReference)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def Delete(self, reference: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureReference) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetEnumerator(self, referenceEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureReferenceEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignatureRelationshipReference(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{57babac6-9d4a-4e50-8b86-e5d4051eae7c}')
    @commethod(3)
    def GetSourceUri(self, sourceUri: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def GetDigestMethod(self, digestMethod: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetDigestValue(self, digestValue: POINTER(POINTER(Byte)), count: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetTransformMethod(self, transformMethod: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetRelationshipSigningOption(self, relationshipSigningOption: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_RELATIONSHIPS_SIGNING_OPTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def GetRelationshipSelectorEnumerator(self, selectorEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSelectorEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignatureRelationshipReferenceEnumerator(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{773ba3e4-f021-48e4-aa04-9816db5d3495}')
    @commethod(3)
    def MoveNext(self, hasNext: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def MovePrevious(self, hasPrevious: POINTER(win32more.Windows.Win32.Foundation.BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetCurrent(self, relationshipReference: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureRelationshipReference)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def Clone(self, copy: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureRelationshipReferenceEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSignatureRelationshipReferenceSet(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{9f863ca5-3631-404c-828d-807e0715069b}')
    @commethod(3)
    def Create(self, sourceUri: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcUri, digestMethod: win32more.Windows.Win32.Foundation.PWSTR, relationshipSigningOption: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_RELATIONSHIPS_SIGNING_OPTION, selectorSet: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSelectorSet, transformMethod: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD, relationshipReference: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureRelationshipReference)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def CreateRelationshipSelectorSet(self, selectorSet: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcRelationshipSelectorSet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def Delete(self, relationshipReference: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureRelationshipReference) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def GetEnumerator(self, relationshipReferenceEnumerator: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureRelationshipReferenceEnumerator)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcSigningOptions(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{50d2d6a5-7aeb-46c0-b241-43ab0e9b407e}')
    @commethod(3)
    def GetSignatureId(self, signatureId: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(4)
    def SetSignatureId(self, signatureId: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(5)
    def GetSignatureMethod(self, signatureMethod: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(6)
    def SetSignatureMethod(self, signatureMethod: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(7)
    def GetDefaultDigestMethod(self, digestMethod: POINTER(win32more.Windows.Win32.Foundation.PWSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def SetDefaultDigestMethod(self, digestMethod: win32more.Windows.Win32.Foundation.PWSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetCertificateEmbeddingOption(self, embeddingOption: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CERTIFICATE_EMBEDDING_OPTION)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def SetCertificateEmbeddingOption(self, embeddingOption: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CERTIFICATE_EMBEDDING_OPTION) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetTimeFormat(self, timeFormat: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_TIME_FORMAT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def SetTimeFormat(self, timeFormat: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_TIME_FORMAT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetSignaturePartReferenceSet(self, partReferenceSet: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignaturePartReferenceSet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def GetSignatureRelationshipReferenceSet(self, relationshipReferenceSet: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureRelationshipReferenceSet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def GetCustomObjectSet(self, customObjectSet: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureCustomObjectSet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def GetCustomReferenceSet(self, customReferenceSet: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcSignatureReferenceSet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def GetCertificateSet(self, certificateSet: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcCertificateSet)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def GetSignaturePartName(self, signaturePartName: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def SetSignaturePartName(self, signaturePartName: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IOpcUri(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUri
    _iid_ = Guid('{bc9c1b9b-d62c-49eb-aef0-3b4e0b28ebed}')
    @commethod(28)
    def GetRelationshipsPartUri(self, relationshipPartUri: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def GetRelativeUri(self, targetPartUri: win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri, relativeUri: POINTER(win32more.Windows.Win32.System.Com.IUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def CombinePartUri(self, relativeUri: win32more.Windows.Win32.System.Com.IUri, combinedUri: POINTER(win32more.Windows.Win32.Storage.Packaging.Opc.IOpcPartUri)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
OPC_CANONICALIZATION_METHOD = Int32
OPC_CANONICALIZATION_NONE: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD = 0
OPC_CANONICALIZATION_C14N: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD = 1
OPC_CANONICALIZATION_C14N_WITH_COMMENTS: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CANONICALIZATION_METHOD = 2
OPC_CERTIFICATE_EMBEDDING_OPTION = Int32
OPC_CERTIFICATE_IN_CERTIFICATE_PART: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CERTIFICATE_EMBEDDING_OPTION = 0
OPC_CERTIFICATE_IN_SIGNATURE_PART: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CERTIFICATE_EMBEDDING_OPTION = 1
OPC_CERTIFICATE_NOT_EMBEDDED: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_CERTIFICATE_EMBEDDING_OPTION = 2
OPC_COMPRESSION_OPTIONS = Int32
OPC_COMPRESSION_NONE: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_COMPRESSION_OPTIONS = -1
OPC_COMPRESSION_NORMAL: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_COMPRESSION_OPTIONS = 0
OPC_COMPRESSION_MAXIMUM: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_COMPRESSION_OPTIONS = 1
OPC_COMPRESSION_FAST: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_COMPRESSION_OPTIONS = 2
OPC_COMPRESSION_SUPERFAST: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_COMPRESSION_OPTIONS = 3
OPC_READ_FLAGS = Int32
OPC_READ_DEFAULT: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_READ_FLAGS = 0
OPC_VALIDATE_ON_LOAD: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_READ_FLAGS = 1
OPC_CACHE_ON_ACCESS: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_READ_FLAGS = 2
OPC_RELATIONSHIPS_SIGNING_OPTION = Int32
OPC_RELATIONSHIP_SIGN_USING_SELECTORS: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_RELATIONSHIPS_SIGNING_OPTION = 0
OPC_RELATIONSHIP_SIGN_PART: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_RELATIONSHIPS_SIGNING_OPTION = 1
OPC_RELATIONSHIP_SELECTOR = Int32
OPC_RELATIONSHIP_SELECT_BY_ID: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_RELATIONSHIP_SELECTOR = 0
OPC_RELATIONSHIP_SELECT_BY_TYPE: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_RELATIONSHIP_SELECTOR = 1
OPC_SIGNATURE_TIME_FORMAT = Int32
OPC_SIGNATURE_TIME_FORMAT_MILLISECONDS: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_TIME_FORMAT = 0
OPC_SIGNATURE_TIME_FORMAT_SECONDS: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_TIME_FORMAT = 1
OPC_SIGNATURE_TIME_FORMAT_MINUTES: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_TIME_FORMAT = 2
OPC_SIGNATURE_TIME_FORMAT_DAYS: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_TIME_FORMAT = 3
OPC_SIGNATURE_TIME_FORMAT_MONTHS: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_TIME_FORMAT = 4
OPC_SIGNATURE_TIME_FORMAT_YEARS: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_TIME_FORMAT = 5
OPC_SIGNATURE_VALIDATION_RESULT = Int32
OPC_SIGNATURE_VALID: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_VALIDATION_RESULT = 0
OPC_SIGNATURE_INVALID: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_SIGNATURE_VALIDATION_RESULT = -1
OPC_STREAM_IO_MODE = Int32
OPC_STREAM_IO_READ: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_STREAM_IO_MODE = 1
OPC_STREAM_IO_WRITE: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_STREAM_IO_MODE = 2
OPC_URI_TARGET_MODE = Int32
OPC_URI_TARGET_MODE_INTERNAL: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_URI_TARGET_MODE = 0
OPC_URI_TARGET_MODE_EXTERNAL: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_URI_TARGET_MODE = 1
OPC_WRITE_FLAGS = Int32
OPC_WRITE_DEFAULT: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_WRITE_FLAGS = 0
OPC_WRITE_FORCE_ZIP32: win32more.Windows.Win32.Storage.Packaging.Opc.OPC_WRITE_FLAGS = 1
OpcFactory = Guid('{6b2d6ba0-9f3e-4f27-920b-313cc426a39e}')


make_ready(__name__)
